
RELEASE_VERSION='0.0.368745335'
BUILD_DATE='Fri Sep 10 14:33:51 UTC 2021'
BUILD_MACHINE_INFO='Linux runner-mvj-ljo-project-28359933-concurrent-1snpvq 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1580442716'
GIT_COMMIT_SHA='27f72fb374a87fb493bcfd62b6a28d621c124a27'
GIT_BRANCH='main'
